@@ -1,7 +1,7 @@
 #ifndef CONNECT___NCBI_USAGE_REPORT__HPP
 #define CONNECT___NCBI_USAGE_REPORT__HPP
 
-/* $Id: ncbi_usage_report.hpp 602851 2020-03-03 18:47:23Z ivanov $
+/* $Id: ncbi_usage_report.hpp 617219 2020-09-28 17:23:04Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -29,7 +29,7 @@
  * Authors:  Vladislav Evgeniev, Vladimir Ivanov
  *
  * File Description:
- *   Log usage information to NCBI pinger.
+ *   Log usage information to NCBI "pinger".
  *
  */
 
@@ -75,7 +75,7 @@ public:
         fOS         = 1 << 3,   ///< OS name ("os")
         fHost       = 1 << 4,   ///< Host name ("host")
         //
-        fDefault    = fAppName | fAppVersion | fOS | fHost
+        fDefault    = fAppName | fAppVersion | fOS
     };
     typedef int TWhat;  ///< Binary OR of "EWhat"
 };
@@ -325,10 +325,10 @@ public:
     /// to allow checking reporting progress or failures, see EState for a list of states.
     /// @sa 
     ///   EState, CUsageReport::Send()
-    virtual void OnStateChange(EState state) {};
+    virtual void OnStateChange(EState /*state*/) {};
 
     /// Copy constructor.
-    CUsageReportJob(const CUsageReportJob& other) { x_CopyFrom(other); };
+    CUsageReportJob(const CUsageReportJob& other) : CUsageReportParameters(other) { m_State = other.m_State; };
     /// Copy assignment operator.
     CUsageReportJob& operator=(const CUsageReportJob& other) { x_CopyFrom(other); return *this; };
     
