@@ -1,7 +1,7 @@
 #ifndef CORELIB___NCBIMISC__HPP
 #define CORELIB___NCBIMISC__HPP
 
-/*  $Id: ncbimisc.hpp 607883 2020-05-08 15:09:10Z grichenk $
+/*  $Id: ncbimisc.hpp 609927 2020-06-08 16:52:43Z grichenk $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -874,8 +874,13 @@ const TSeqPos kInvalidSeqPos = ((TSeqPos) (-1));
 /// Use this typedef rather than its expansion, which may change.
 typedef int TSignedSeqPos;
 
-/// Type for Taxon1-name.taxid
+/// Taxon id type
 typedef int TTaxId;
+# define TAX_ID_TO(T, tax_id) (static_cast<T>(tax_id))
+# define TAX_ID_FROM(T, value) (static_cast<ncbi::TTaxId>(value))
+# define TAX_ID_CONST(id) id
+#define ZERO_TAX_ID TAX_ID_CONST(0)
+#define INVALID_TAX_ID TAX_ID_CONST(-1)
 
 /// Type for sequence GI.
 ///
@@ -1029,25 +1034,25 @@ class CConstGIChecker {
 public:
     static const TIntId value = gi;
 };
-#define GI_CONST(gi) (TGi(CConstGIChecker<gi>::value))
+#define GI_CONST(gi) (ncbi::TGi(CConstGIChecker<gi>::value))
 #define ZERO_GI GI_CONST(0)
 #define INVALID_GI GI_CONST(-1)
 
 /// Temporary macros to convert TGi to other types (int, unsigned etc.).
-#define GI_TO(T, gi) (static_cast<T>(TIntId(gi)))
-#define GI_FROM(T, value) (TGi(static_cast<TIntId>(value)))
+#define GI_TO(T, gi) (static_cast<T>(ncbi::TIntId(gi)))
+#define GI_FROM(T, value) (ncbi::TGi(static_cast<ncbi::TIntId>(value)))
 
-#define ENTREZ_ID_CONST(id) (TEntrezId(CConstGIChecker<id>::value))
+#define ENTREZ_ID_CONST(id) (ncbi::TEntrezId(CConstGIChecker<id>::value))
 #define ZERO_ENTREZ_ID ENTREZ_ID_CONST(0)
 #define INVALID_ENTREZ_ID ENTREZ_ID_CONST(-1)
 
 /// Temporary macros to convert TEntrezId to other types (int, unsigned etc.).
-#define ENTREZ_ID_TO(T, entrez_id) (static_cast<T>(TIntId(entrez_id)))
-#define ENTREZ_ID_FROM(T, value) (TEntrezId(static_cast<TIntId>(value)))
+#define ENTREZ_ID_TO(T, entrez_id) (static_cast<T>(ncbi::TIntId(entrez_id)))
+#define ENTREZ_ID_FROM(T, value) (ncbi::TEntrezId(static_cast<ncbi::TIntId>(value)))
 
 /// Convert gi-compatible int to/from other types.
 #define INT_ID_TO(T, id) (static_cast<T>(id))
-#define INT_ID_FROM(T, value) (static_cast<TIntId>(value))
+#define INT_ID_FROM(T, value) (static_cast<ncbi::TIntId>(value))
 
 
 /// Helper address class
