@@ -1,7 +1,7 @@
 #ifndef CORELIB___TEST_BOOST__HPP
 #define CORELIB___TEST_BOOST__HPP
 
-/*  $Id: test_boost.hpp 604629 2020-03-31 13:43:18Z ivanov $
+/*  $Id: test_boost.hpp 617213 2020-09-28 17:22:30Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -64,7 +64,11 @@
 #endif
 
 #include <boost/version.hpp>
-#include <boost/test/auto_unit_test.hpp>
+#if BOOST_VERSION >= 107000
+#  include <boost/test/unit_test.hpp>
+#else 
+#  include <boost/test/auto_unit_test.hpp>
+#endif
 #include <boost/test/floating_point_comparison.hpp>
 #include <boost/test/framework.hpp>
 #include <boost/test/execution_monitor.hpp>
