@@ -1,7 +1,7 @@
 #ifndef OBJTOOLS_FORMAT___FLAT_FILE_CONFIG__HPP
 #define OBJTOOLS_FORMAT___FLAT_FILE_CONFIG__HPP
 
-/*  $Id: flat_file_config.hpp 607400 2020-05-04 14:18:10Z ivanov $
+/*  $Id: flat_file_config.hpp 614736 2020-08-21 13:43:48Z fukanchi $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -89,7 +89,7 @@ public:
     virtual void FormatTranscriptId(string& str, const CSeq_id& seq_id, const string& nuc_id) const = 0;
     virtual void FormatNucSearch(CNcbiOstream& os, const string& id) const = 0;
     virtual void FormatNucId(string& str, const CSeq_id& seq_id, TIntId gi, const string& acc_id) const = 0;
-    virtual void FormatTaxid(string& str, const int taxid, const string& taxname) const = 0;
+    virtual void FormatTaxid(string& str, const TTaxId taxid, const string& taxname) const = 0;
     virtual void FormatLocation(string& str, const CSeq_loc& loc, TIntId gi, const string& visible_text) const = 0;
     virtual void FormatModelEvidence(string& str, const SModelEvidance& me) const = 0;
     virtual void FormatTranscript(string& str, const string& name) const = 0;
@@ -107,7 +107,7 @@ public:
     void FormatTranscriptId(string& str, const CSeq_id& seq_id, const string& nuc_id) const;
     void FormatNucSearch(CNcbiOstream& os, const string& id) const;
     void FormatNucId(string& str, const CSeq_id& seq_id, TIntId gi, const string& acc_id) const;
-    void FormatTaxid(string& str, const int taxid, const string& taxname) const;
+    void FormatTaxid(string& str, const TTaxId taxid, const string& taxname) const;
     void FormatLocation(string& str, const CSeq_loc& loc, TIntId gi, const string& visible_text) const;
     void FormatModelEvidence(string& str, const SModelEvidance& me) const;
     void FormatTranscript(string& str, const string& name) const;
@@ -200,7 +200,8 @@ public:
         fIgnoreExistingTitle   = 1 << 13,
         fGeneRNACDSFeatures    = 1 << 14,
         fShowFtablePeptides    = 1 << 15,
-        fDisableReferenceCache = 1 << 16
+        fDisableReferenceCache = 1 << 16,
+        fShowDeflineModifiers  = 1 << 17
     };
 
     enum EView {
@@ -216,7 +217,9 @@ public:
         ePolicy_Adaptive = 0,
         ePolicy_Internal,
         ePolicy_External,
-        ePolicy_Exhaustive
+        ePolicy_Exhaustive,
+        ePolicy_Ftp,
+        ePolicy_Web
     };
 
     // These flags are used to select the GenBank sections to print or skip.
@@ -390,7 +393,8 @@ public:
                     TStyle  style = eStyle_Normal,
                     TFlags  flags = 0,
                     TView   view = fViewNucleotides,
-                    TPolicy policy = ePolicy_Adaptive);
+                    TPolicy policy = ePolicy_Adaptive,
+                    TCustom custom = 0);
 
     // destructor
     ~CFlatFileConfig(void);
@@ -494,12 +498,16 @@ public:
     bool IsPolicyInternal(void) const { return m_Policy == ePolicy_Internal; }
     bool IsPolicyExternal (void) const { return m_Policy == ePolicy_External;  }
     bool IsPolicyExhaustive (void) const { return m_Policy == ePolicy_Exhaustive;  }
+    bool IsPolicyFtp (void) const { return m_Policy == ePolicy_Ftp;  }
+    bool IsPolicyWeb (void) const { return m_Policy == ePolicy_Web;  }
     // setters
     void SetPolicy(const TPolicy& Policy) { m_Policy = Policy;  }
     void SetPolicyAdaptive (void) { m_Policy = ePolicy_Adaptive;  }
     void SetPolicyInternal(void) { m_Policy = ePolicy_Internal; }
     void SetPolicyExternal (void) { m_Policy = ePolicy_External;  }
     void SetPolicyExhaustive (void) { m_Policy = ePolicy_Exhaustive;  }
+    void SetPolicyFtp (void) { m_Policy = ePolicy_Ftp;  }
+    void SetPolicyWeb (void) { m_Policy = ePolicy_Web;  }
 
     // -- Flags
     // getters
@@ -617,6 +625,7 @@ public:
     bool GeneRNACDSFeatures    (void) const;
     bool ShowFtablePeptides    (void) const;
     bool DisableReferenceCache (void) const;
+    bool ShowDeflineModifiers  (void) const;
 
     // setters
     void SetCustom(const TCustom& custom) { m_Custom = custom; }
@@ -633,10 +642,17 @@ public:
     CFlatFileConfig& SetGeneRNACDSFeatures    (bool val = true);
     CFlatFileConfig& SetShowFtablePeptides    (bool val = true);
     CFlatFileConfig& SetDisableReferenceCache (bool val = true);
+    CFlatFileConfig& SetShowDeflineModifiers  (bool val = true);
 
     // adjust mode dependant flags for RefSeq
     void SetRefSeqConventions(void);
 
+  int GetFeatDepth(void) const { return m_FeatDepth; }
+  void SetFeatDepth(const int featDepth) { m_FeatDepth = featDepth; }
+
+  int GetGapDepth(void) const { return m_GapDepth; }
+  void SetGapDepth(const int gapDepth) { m_GapDepth = gapDepth; }
+
 
     void SetGenbankBlocks(const TGenbankBlocks& genbank_blocks) 
     {
@@ -723,6 +739,8 @@ private:
     const ICanceled * m_pCanceledCallback; // instance does NOT own it
     bool        m_BasicCleanup;
     TCustom     m_Custom;
+    int         m_FeatDepth;
+    int         m_GapDepth;
 #ifdef NEW_HTML_FMT
     CRef<IHTMLFormatter> m_html_formatter;
 #endif
@@ -823,6 +841,7 @@ CUSTOM_ARG_IMP(IgnoreExistingTitle)
 CUSTOM_ARG_IMP(GeneRNACDSFeatures)
 CUSTOM_ARG_IMP(ShowFtablePeptides)
 CUSTOM_ARG_IMP(DisableReferenceCache)
+CUSTOM_ARG_IMP(ShowDeflineModifiers)
 
 #undef FLAG_ARG_IMP
 #undef FLAG_ARG_GET
