@@ -1,7 +1,7 @@
 #ifndef OBJTOOLS_READERS___FASTA__HPP
 #define OBJTOOLS_READERS___FASTA__HPP
 
-/*  $Id: fasta.hpp 598690 2019-12-12 14:55:16Z foleyjp $
+/*  $Id: fasta.hpp 612524 2020-07-23 11:37:59Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -341,6 +341,11 @@ private:
                      TSeqPos line_number,
                      CBioseq& bioseq,
                      ILineErrorListener* pMessageListener);
+
+    void x_SetDeflineParseInfo(SDefLineParseInfo& info);
+
+    bool m_bModifiedMaxIdLength=false;
+
 protected:
     struct SGap : public CObject {
         enum EKnownSize {
