@@ -1,7 +1,7 @@
 #ifndef STREAMITER__HPP
 #define STREAMITER__HPP
 
-/*  $Id: streamiter.hpp 583376 2019-03-27 18:06:15Z dicuccio $
+/*  $Id: streamiter.hpp 609566 2020-06-03 19:29:58Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -924,7 +924,7 @@ CObjectIStreamIterator<TRoot>::CData::x_NextSeqWithFilter(const CObjectInfo& obj
             case eAllRandom:
                 done.insert(mi_now);
                 // no break
-                /* FALLTHROUGH */
+                NCBI_FALLTHROUGH;
             case eAllSeq:
                 {
                     CObjectInfo oi = minfo.GetMember().GetTypeFamily() == eTypeFamilyPointer ?
