@@ -1,4 +1,4 @@
-/* $Id: blast_engine.c 604741 2020-04-01 15:15:25Z ivanov $
+/* $Id: blast_engine.c 617226 2020-09-28 18:25:19Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -79,9 +79,9 @@
 #define CONV_NUCL2PROT_COORDINATES(length) (length) / CODON_LENGTH
 
 NCBI_XBLAST_EXPORT const int   kBlastMajorVersion = 2;
-NCBI_XBLAST_EXPORT const int   kBlastMinorVersion = 10;
-NCBI_XBLAST_EXPORT const int   kBlastPatchVersion = 1;
-NCBI_XBLAST_EXPORT const char* kBlastReleaseDate = "June-01-2020";
+NCBI_XBLAST_EXPORT const int   kBlastMinorVersion = 11;
+NCBI_XBLAST_EXPORT const int   kBlastPatchVersion = 0;
+NCBI_XBLAST_EXPORT const char* kBlastReleaseDate = "Oct-15-2020";
 
 /** Structure to be passed to s_BlastSearchEngineCore, containing pointers
     to various preallocated structures and arrays. */
@@ -992,6 +992,9 @@ s_BlastSetUpAuxStructures(const BlastSeqSrc* seq_src,
     Boolean jumper = (ext_options->ePrelimGapExt == eJumperWithTraceback);
     Int4 offset_array_size = GetOffsetArraySize(lookup_wrap);
 
+    if(phi_lookup) {
+    	offset_array_size = PHI_MAX_HIT;
+    }
     ASSERT(seq_src);
 
     *aux_struct_ptr = aux_struct = (BlastCoreAuxStruct*)
