@@ -1,4 +1,4 @@
-/*  $Id: blast_app_util.cpp 592833 2019-09-09 13:01:28Z fongah2 $
+/*  $Id: blast_app_util.cpp 615351 2020-08-31 15:38:53Z fukanchi $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -915,47 +915,6 @@ GetSubjectFile(const CArgs& args)
 	return filename;
 }
 
-
-void CBlastAppDiagHandler::Post(const SDiagMessage & mess)
-{
-	if(m_handler != NULL) {
-		m_handler->Post(mess);
-	}
-	if(m_save) {
-		CRef<CBlast4_error> d(new CBlast4_error);
-		string m;
-		mess.Write(m);
-		d->SetMessage(NStr::Sanitize(m));
-		d->SetCode((int)mess.m_Severity);
-		{
-			DEFINE_STATIC_MUTEX(mx);
-			CMutexGuard guard(mx);
-			m_messages.push_back(d);
-		}
-	}
-}
-
-void CBlastAppDiagHandler::ResetMessages()
-{
-	DEFINE_STATIC_MUTEX(mx);
-	CMutexGuard guard(mx);
-	m_messages.clear();
-}
-
-CBlastAppDiagHandler::~CBlastAppDiagHandler()
-{
-	if(m_handler) {
-		SetDiagHandler(m_handler);
-		m_handler = NULL;
-	}
-}
-
-void CBlastAppDiagHandler::DoNotSaveMessages(void)
-{
-	m_save = false;
-	ResetMessages();
-}
-
 void PrintErrorArchive(const CArgs & a, const list<CRef<CBlast4_error> > & msg)
 {
 	try {
@@ -983,4 +942,41 @@ void QueryBatchCleanup()
 
 }
 
+void LogQueryInfo(CBlastUsageReport & report, const CBlastInput & q_info)
+{
+	report.AddParam(CBlastUsageReport::eTotalQueryLength, q_info.GetTotalLengthProcessed());
+	report.AddParam(CBlastUsageReport::eNumQueries, q_info.GetNumSeqsProcessed());
+}
+
+
+void LogRPSBlastOptions(blast::CBlastUsageReport & report, const CBlastOptions & opt)
+{
+	report.AddParam(CBlastUsageReport::eProgram, Blast_ProgramNameFromType(opt.GetProgramType()));
+	report.AddParam(CBlastUsageReport::eEvalueThreshold, opt.GetEvalueThreshold());
+	report.AddParam(CBlastUsageReport::eHitListSize, opt.GetHitlistSize());
+    report.AddParam(CBlastUsageReport::eCompBasedStats, opt.GetCompositionBasedStats());
+}
+
+void LogRPSCmdOptions(blast::CBlastUsageReport & report, const CBlastAppArgs & args)
+{
+	if (args.GetBlastDatabaseArgs().NotEmpty() &&
+		args.GetBlastDatabaseArgs()->GetSearchDatabase().NotEmpty() &&
+		args.GetBlastDatabaseArgs()->GetSearchDatabase()->GetSeqDb().NotEmpty()) {
+
+		CRef<CSeqDB> db = args.GetBlastDatabaseArgs()->GetSearchDatabase()->GetSeqDb();
+		string db_name = db->GetDBNameList();
+		int off = db_name.find_last_of(CFile::GetPathSeparator());
+	    if (off != -1) {
+	    	db_name.erase(0, off+1);
+		}
+		report.AddParam(CBlastUsageReport::eDBName, db_name);
+		report.AddParam(CBlastUsageReport::eDBLength, (Int8) db->GetTotalLength());
+		report.AddParam(CBlastUsageReport::eDBNumSeqs, db->GetNumSeqs());
+		report.AddParam(CBlastUsageReport::eDBDate, db->GetDate());
+	}
+
+	if(args.GetFormattingArgs().NotEmpty()){
+		report.AddParam(CBlastUsageReport::eOutputFmt, args.GetFormattingArgs()->GetFormattedOutputChoice());
+	}
+}
 END_NCBI_SCOPE
