@@ -1,4 +1,4 @@
-/*  $Id: deltablast_app.cpp 570608 2018-09-12 12:17:57Z fongah2 $
+/*  $Id: deltablast_app.cpp 615345 2020-08-31 15:38:03Z fukanchi $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -63,6 +63,13 @@ public:
         CRef<CVersion> version(new CVersion());
         version->SetVersionInfo(new CBlastVersion());
         SetFullVersion(version);
+        m_StopWatch.Start();
+        if (m_UsageReport.IsEnabled()) {
+        	m_UsageReport.AddParam(CBlastUsageReport::eVersion, GetVersion().Print());
+        }
+    }
+    ~CDeltaBlastApp() {
+    	m_UsageReport.AddParam(CBlastUsageReport::eRunTime, m_StopWatch.Elapsed());
     }
 private:
     /** @inheritDoc */
@@ -100,6 +107,8 @@ private:
     CRef<CBlastAncillaryData> m_AncillaryData;
 
     CBlastAppDiagHandler m_bah;
+    CBlastUsageReport m_UsageReport;
+    CStopWatch m_StopWatch;
 };
 
 void CDeltaBlastApp::Init()
@@ -440,11 +449,15 @@ int CDeltaBlastApp::Run(void)
             opts_hndl->GetOptions().DebugDumpText(NcbiCerr, "BLAST options", 1);
         }
 
+        LogQueryInfo(m_UsageReport, input);
+        formatter.LogBlastSearchInfo(m_UsageReport);
     } CATCH_ALL(status)
     if(!m_bah.GetMessages().empty()) {
      	const CArgs & a = GetArgs();
      	PrintErrorArchive(a, m_bah.GetMessages());
     }
+	m_UsageReport.AddParam(CBlastUsageReport::eNumThreads, (int) m_CmdLineArgs->GetNumThreads());
+    m_UsageReport.AddParam(CBlastUsageReport::eExitStatus, status);
     return status;
 }
 
