@@ -1,4 +1,4 @@
-/*  $Id: scope.cpp 603742 2020-03-16 17:25:41Z ivanov $
+/*  $Id: scope.cpp 610058 2020-06-10 16:19:48Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -328,6 +328,18 @@ void CScope::ResetDataAndHistory(ERemoveDataLoaders)
 }
 
 
+void CScope::RemoveFromHistory(const CSeq_id_Handle& seq_id)
+{
+    m_Impl->RemoveFromHistory(seq_id);
+}
+
+
+void CScope::RemoveFromHistory(const CSeq_id& seq_id)
+{
+    RemoveFromHistory(CSeq_id_Handle::GetHandle(seq_id));
+}
+
+
 void CScope::RemoveFromHistory(const CBioseq_Handle& bioseq,
                                EActionIfLocked action)
 {
