@@ -1,4 +1,4 @@
-/*  $Id: tse_info.cpp 606922 2020-04-28 18:58:25Z ivanov $
+/*  $Id: tse_info.cpp 611227 2020-07-01 11:37:30Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -428,7 +428,7 @@ CBioObjectId CTSE_Info::x_RegisterBioObject(CTSE_Info_Object& info)
     }
         
     uniq_id = CBioObjectId(CBioObjectId::eUniqNumber,
-                           m_InternalBioObjNumber++);
+                           ++m_InternalBioObjNumber);
     m_BioObjects[uniq_id] = &info;
     return uniq_id;
 }
