@@ -1,4 +1,4 @@
-/*  $Id: autodef.cpp 607821 2020-05-07 19:13:41Z ivanov $
+/*  $Id: autodef.cpp 611612 2020-07-08 17:43:23Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -880,6 +880,9 @@ string CAutoDef::x_GetNonFeatureListEnding()
         case CAutoDefOptions::eListAllFeatures:
             end = " sequence.";
             break;
+        case CAutoDefOptions::eWholeGenomeShotgunSequence:
+            end = " whole genome shotgun sequence.";
+            break;
         default:
             break;
     }
