@@ -1,7 +1,7 @@
 #ifndef OBJTOOLS_WRITERS_WRITEDB__WRITEDB_IMPL_HPP
 #define OBJTOOLS_WRITERS_WRITEDB__WRITEDB_IMPL_HPP
 
-/*  $Id: writedb_impl.hpp 588812 2019-07-01 12:29:10Z fongah2 $
+/*  $Id: writedb_impl.hpp 616350 2020-09-15 12:19:05Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -530,7 +530,7 @@ private:
                                   const vector< vector<int> >    & membbits,
                                   const vector< vector<int> >    & linkouts,
                                   int                              pig,
-                                  set<Int4>                      & tax_ids,
+                                  set<TTaxId>                    & tax_ids,
                                   int                              OID=-1,
                                   bool                             parse_ids=true,
                                   bool                             long_seqid=false,
@@ -610,7 +610,7 @@ private:
     /// Binary header in format that will be written to disk.
     string m_BinHdr;
 
-    set<Int4> m_TaxIds;
+    set<TTaxId> m_TaxIds;
 
     // Volumes
 
