@@ -1,4 +1,4 @@
-/*  $Id: loc_edit.cpp 601240 2020-02-04 16:06:49Z ludwigf $
+/*  $Id: loc_edit.cpp 609624 2020-06-04 15:45:32Z ivanov $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -2608,8 +2608,10 @@ bool ExtendPartialFeatureEnds(CBioseq_Handle bsh)
             CRef<CSeq_feat> new_cds(new CSeq_feat());
             new_cds->Assign(*(f->GetOriginalSeq_feat()));
 
-            if (AdjustFeatureEnd5(*new_cds, related_features, bsh.GetScope()) ||
-                AdjustFeatureEnd3(*new_cds, related_features, bsh.GetScope())) {
+            const bool adjusted_5prime = AdjustFeatureEnd5(*new_cds, related_features, bsh.GetScope());
+            const bool adjusted_3prime = AdjustFeatureEnd3(*new_cds, related_features, bsh.GetScope());
+
+            if (adjusted_5prime || adjusted_3prime) {
                 feature::RetranslateCDS(*new_cds, bsh.GetScope());
                 CSeq_feat_EditHandle feh(*f);
                 feh.Replace(*new_cds);
