@@ -1,4 +1,4 @@
-/*  $Id: remote_updater.cpp 605109 2020-04-07 11:01:53Z ivanov $
+/*  $Id: remote_updater.cpp 614634 2020-08-20 13:02:41Z fukanchi $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -57,6 +57,8 @@
 #include <objects/general/Name_std.hpp>
 
 #include <objtools/edit/remote_updater.hpp>
+#include <objtools/edit/edit_error.hpp>
+#include <objtools/logging/listener.hpp>
 
 #include <common/test_assert.h>  /* This header must go last */
 
@@ -69,7 +71,7 @@ DEFINE_CLASS_STATIC_MUTEX(CRemoteUpdater::m_static_mutex);
 namespace
 {
 
-int FindPMID(CMLAClient& mlaClient, const CPub_equiv::Tdata& arr)
+TEntrezId FindPMID(const list<CRef<CPub>>& arr)
 {
     for (auto pPub : arr) {
         if (pPub->IsPmid()) {
@@ -77,36 +79,93 @@ int FindPMID(CMLAClient& mlaClient, const CPub_equiv::Tdata& arr)
         }
 
     }
-    return 0;
+    return ZERO_ENTREZ_ID;
 }
 
-// the method is not used at the momment
-void CreatePubPMID(CMLAClient& mlaClient, CPub_equiv::Tdata& arr, int id)
-{
-    try {
-        CPubMedId req(id);
-        CRef<CPub> new_pub = mlaClient.AskGetpubpmid(req);
-        if (new_pub.NotEmpty())
-        {
-            // authors come back in a weird format that we need
-            // to convert to ISO
-            if (new_pub->IsSetAuthors())
-               CRemoteUpdater::ConvertToStandardAuthors((CAuth_list&)new_pub->GetAuthors());
 
-            arr.clear();
-            CRef<CPub> new_pmid(new CPub);
-            new_pmid->SetPmid().Set(id);
-            arr.push_back(new_pmid);
-            arr.push_back(new_pub);
-        }
-    } catch(...) {
-        // don't worry if we can't look it up
+static bool s_IsConnectionFailure(EError_val mlaErrorVal) {
+    switch(mlaErrorVal) {
+    case eError_val_cannot_connect_pmdb:
+    case eError_val_cannot_connect_searchbackend_pmdb:
+        return true;
+    default:
+        break;
     }
+    return false;
+}
 
+
+CRef<CPub> s_GetPubFrompmid(CMLAClient& mlaClient, TEntrezId id, int maxAttempts, IObjtoolsListener* pMessageListener)
+{
+    CRef<CPub> result;
+    CPubMedId  request(id);
+    CMLAClient::TReply reply;
+
+    int maxCount = max(1, maxAttempts);
+    for (int count=0; count<maxCount; ++count) { 
+        try {
+            result = mlaClient.AskGetpubpmid(request, &reply);
+            return result;
+        }
+        catch(CException&) {
+            auto errorVal = reply.GetError();
+            auto isConnectionError = s_IsConnectionFailure(errorVal);
+            if (isConnectionError && count<maxCount-1) {
+                continue;
+            }
+
+            CNcbiOstrstream oss;
+            oss << "Failed to retrieve publication for PMID " 
+                << id 
+                << ". ";
+            if (isConnectionError) {
+                oss << count+1 << " attempts made. ";
+            }
+            oss << "CMLAClient : " 
+                << errorVal;
+            string msg = CNcbiOstrstreamToString(oss);
+            if (pMessageListener) {
+                pMessageListener->PutMessage(CObjEditMessage(msg, eDiag_Error));
+                break;
+            }
+            else {
+                NCBI_THROW(CException, eUnknown, msg);
+            }
+        }
+    }
+    return result;
 }
 
 }// end anonymous namespace
 
+bool CRemoteUpdater::xUpdatePubPMID(list<CRef<CPub>>& arr, TEntrezId id)
+{
+    CMLAClient::TReply reply;
+    auto new_pub = 
+        s_GetPubFrompmid(*m_mlaClient, id, m_MaxMlaAttempts, m_pMessageListener);
+    if (!new_pub) {
+        return false;
+    }
+
+    // authors come back in a weird format that we need
+    // to convert to ISO
+    if (new_pub->IsSetAuthors())
+        CRemoteUpdater::ConvertToStandardAuthors((CAuth_list&)new_pub->GetAuthors());
+
+    arr.clear();
+    CRef<CPub> new_pmid(new CPub);
+    new_pmid->SetPmid().Set(id);
+    arr.push_back(new_pmid);
+    arr.push_back(new_pub);
+    return true;
+}
+
+
+void CRemoteUpdater::SetMaxMlaAttempts(int maxAttempts) 
+{
+    m_MaxMlaAttempts = maxAttempts;
+}
+
 
 class CCachedTaxon3_impl
 {
@@ -131,6 +190,30 @@ public:
         }
     }
 
+    CRef<COrg_ref> GetOrg(const COrg_ref& org, IObjtoolsListener* pMessageListener=nullptr)
+    {
+        CRef<COrg_ref> result;
+        CRef<CT3Reply> reply = GetOrgReply(org);
+        if (reply->IsError() && pMessageListener)
+        {
+            const string& error_message = 
+                "Taxon update: " +
+                (org.IsSetTaxname() ? org.GetTaxname() : NStr::NumericToString(org.GetTaxId())) + ": " +
+                reply->GetError().GetMessage();
+
+            pMessageListener->PutMessage(
+                    CObjEditMessage(error_message, eDiag_Error));
+        
+        }
+        else
+        if (reply->IsData() && reply->SetData().IsSetOrg())
+        {
+            result.Reset(&reply->SetData().SetOrg());
+        }
+        return result;
+    }
+
+
     CRef<COrg_ref> GetOrg(const COrg_ref& org, CRemoteUpdater::FLogger f_logger)
     {
         CRef<COrg_ref> result;
@@ -141,14 +224,8 @@ public:
                 "Taxon update: " +
                 (org.IsSetTaxname() ? org.GetTaxname() : NStr::IntToString(org.GetTaxId())) + ": " +
                 reply->GetError().GetMessage();
-
-/*
-            logger->PutError(*auto_ptr<CLineError>(
-                CLineError::Create(ILineError::eProblem_Unset, eDiag_Warning, "", 0,
-                string("Taxon update: ") + 
-                (org.IsSetTaxname() ? org.GetTaxname() : NStr::IntToString(org.GetTaxId())) + ": " +
-                reply->GetError().GetMessage())));
-            */
+        
+            f_logger(error_message);
         }
         else
         if (reply->IsData() && reply->SetData().IsSetOrg())
@@ -218,7 +295,7 @@ protected:
     auto_ptr<CCachedReplyMap> m_cache;
 };
 
-void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeqdesc& obj)
+void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, CSeqdesc& obj)
 {
     if (obj.IsOrg())
     {
@@ -232,7 +309,8 @@ void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeqdesc& obj)
 }
 
 void CRemoteUpdater::xUpdateOrgTaxname(FLogger logger, COrg_ref& org)
-{
+{ // remove after the deprecated UpdateOrgFromTaxon(FLogger, CSeqdes&) 
+  // has been removed.
     CMutexGuard guard(m_Mutex);
 
     int taxid = org.GetTaxId();
@@ -252,6 +330,42 @@ void CRemoteUpdater::xUpdateOrgTaxname(FLogger logger, COrg_ref& org)
     }
 }
 
+void CRemoteUpdater::UpdateOrgFromTaxon(CSeqdesc& desc)
+{
+    if (desc.IsOrg())
+    {
+        xUpdateOrgTaxname(desc.SetOrg());
+    }
+    else
+    if (desc.IsSource() && desc.GetSource().IsSetOrg())
+    {
+        xUpdateOrgTaxname(desc.SetSource().SetOrg());
+    }
+}
+
+
+void CRemoteUpdater::xUpdateOrgTaxname(COrg_ref& org)
+{
+    CMutexGuard guard(m_Mutex);
+
+    TTaxId taxid = org.GetTaxId();
+    if (taxid == ZERO_TAX_ID && !org.IsSetTaxname())
+        return;
+
+    if (m_taxClient.get() == 0)
+    {
+        m_taxClient.reset(new CCachedTaxon3_impl);
+        m_taxClient->Init();
+    }
+        
+    CRef<COrg_ref> new_org = m_taxClient->GetOrg(org, m_pMessageListener);
+    if (new_org.NotEmpty())
+    {
+        org.Assign(*new_org);
+    }
+}
+
+
 CRemoteUpdater& CRemoteUpdater::GetInstance()
 {
     CMutexGuard guard(m_static_mutex);
@@ -261,6 +375,12 @@ CRemoteUpdater& CRemoteUpdater::GetInstance()
     return instance;
 }
 
+CRemoteUpdater::CRemoteUpdater(IObjtoolsListener* pMessageListener) :
+    m_pMessageListener(pMessageListener)
+{
+}
+
+
 CRemoteUpdater::CRemoteUpdater(bool enable_caching)
     :m_enable_caching(enable_caching)
 {
@@ -280,7 +400,7 @@ void CRemoteUpdater::ClearCache()
     }
 }
 
-void CRemoteUpdater::UpdatePubReferences(objects::CSeq_entry_EditHandle& obj)
+void CRemoteUpdater::UpdatePubReferences(CSeq_entry_EditHandle& obj)
 {
     for (CBioseq_CI it(obj); it; ++it)
     {
@@ -336,61 +456,59 @@ void CRemoteUpdater::xUpdatePubReferences(CSeq_entry& entry)
     xUpdatePubReferences(entry.SetDescr());
 }
 
-void CRemoteUpdater::xUpdatePubReferences(objects::CSeq_descr& seq_descr)
+
+
+void CRemoteUpdater::xUpdatePubReferences(CSeq_descr& seq_descr)
 {
     CMutexGuard guard(m_Mutex);
 
-    CSeq_descr::Tdata& descr = seq_descr.Set();
-    size_t count = descr.size();
-    CSeq_descr::Tdata::iterator it = descr.begin();
-
-    for (size_t i=0; i<count; ++it,  ++i)
-    {
-        if (! ( (**it).IsPub() && (**it).GetPub().IsSetPub() ) )
+    for (auto pDesc : seq_descr.Set()) {
+        if (!pDesc->IsPub() || !pDesc->GetPub().IsSetPub()) {
             continue;
+        }   
 
-        CPub_equiv::Tdata& arr = (**it).SetPub().SetPub().Set();
-        if (m_mlaClient.Empty())
-            m_mlaClient.Reset(new CMLAClient);
+        auto& arr = pDesc->SetPub().SetPub().Set();
+        if (m_mlaClient.Empty()) 
+            m_mlaClient.Reset(new CMLAClient());
 
-        int id = FindPMID(*m_mlaClient, arr);
-        if (id>0)
-        {
-            CreatePubPMID(*m_mlaClient, arr, id);
+        auto id = FindPMID(arr);
+        if (id>ZERO_ENTREZ_ID) {
+            xUpdatePubPMID(arr, id);
+            continue;
         }
-        else
-        // nothing was found
-        NON_CONST_ITERATE(CPub_equiv::Tdata, item_it, arr)
-        {
-            if ((**item_it).IsArticle())
-            try
-            {
-                id = m_mlaClient->AskCitmatchpmid(**item_it);
-                if (id>0)
+
+        for (auto pPubEquiv : arr) {
+            if (pPubEquiv->IsArticle()) {
+                CMLAClient::TReply reply;
+                try {
+                    id = ENTREZ_ID_FROM(int, m_mlaClient->AskCitmatchpmid(*pPubEquiv, &reply));
+                }
+                catch(CException& e) 
                 {
-                    CreatePubPMID(*m_mlaClient, arr, id);
+                    continue;
+                }
+                if (id>ZERO_ENTREZ_ID &&
+                    xUpdatePubPMID(arr,id)) {
                     break;
                 }
             }
-            catch(CException& /*ex*/)
-            {
-            }
         }
     }
 }
 
+
 namespace
 {
     typedef set<CRef< CSeqdesc >* > TOwnerSet;
     typedef struct { TOwnerSet owner; CRef<COrg_ref> org_ref; } TOwner;
     typedef map<string, TOwner > TOrgMap;
-    void _UpdateOrgFromTaxon(CRemoteUpdater::FLogger logger, objects::CSeq_entry& entry, TOrgMap& m)
+    void _UpdateOrgFromTaxon(CSeq_entry& entry, TOrgMap& m)
     {
         if (entry.IsSet())
         {
             NON_CONST_ITERATE(CSeq_entry::TSet::TSeq_set, it, entry.SetSet().SetSeq_set())
             {
-                _UpdateOrgFromTaxon(logger, **it, m);
+                _UpdateOrgFromTaxon(**it, m);
             }
         }
 
@@ -404,13 +522,11 @@ namespace
             CRef<COrg_ref> org_ref;
             if (desc.IsOrg())
             {
-                //xUpdateOrgTaxname(logger, desc.SetOrg());
                 org_ref.Reset(&desc.SetOrg());
             }
             else
             if (desc.IsSource() && desc.GetSource().IsSetOrg())
             {
-                //xUpdateOrgTaxname(logger, desc.SetSource().SetOrg());
                 org_ref.Reset(&desc.SetSource().SetOrg());
             }
             if (org_ref)
@@ -442,11 +558,12 @@ namespace
         }
     }
 }
-void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeq_entry& entry)
+
+void CRemoteUpdater::UpdateOrgFromTaxon(CSeq_entry& entry)
 {   
     TOrgMap org_to_update;
 
-    _UpdateOrgFromTaxon(logger, entry, org_to_update); 
+    _UpdateOrgFromTaxon(entry, org_to_update); 
     if (org_to_update.empty())
         return;
 
@@ -475,7 +592,14 @@ void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeq_entry& ent
     }
 }
 
-void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeq_entry_EditHandle& obj)
+void CRemoteUpdater::UpdateOrgFromTaxon(FLogger /*logger*/, CSeq_entry& entry)
+{
+    // this method is deprecated. 
+    // until we remove it, it simply calls the non-deprecated method
+    UpdateOrgFromTaxon(entry);   
+}
+
+void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, CSeq_entry_EditHandle& obj)
 {
     for (CBioseq_CI bioseq_it(obj); bioseq_it; ++bioseq_it)
     {
@@ -486,6 +610,8 @@ void CRemoteUpdater::UpdateOrgFromTaxon(FLogger logger, objects::CSeq_entry_Edit
     }
 }
 
+
+
 namespace
 {
 bool s_IsAllCaps(const string& str)
@@ -663,7 +789,10 @@ void CRemoteUpdater::PostProcessPubs(CSeq_entry_EditHandle& obj)
             PostProcessPubs((CPubdesc&)desc_it->GetPub());
         }
     }
-   
+}
+
+void CRemoteUpdater::SetMLAClient(CMLAClient& mlaClient) {
+    m_mlaClient.Reset(&mlaClient);
 }
 
 END_SCOPE(edit)
