@@ -1,4 +1,4 @@
-/*  $Id: dbsource_item.cpp 577454 2019-01-03 22:58:25Z kans $
+/*  $Id: dbsource_item.cpp 614611 2020-08-20 12:59:34Z fukanchi $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -628,7 +628,7 @@ string CDBSourceItem::x_FormatDBSourceID(const CSeq_id_Handle& idh)
                     GetContext()->Config().GetHTMLFormatter().FormatUniProtId(ht, acc);
                 } else {
                     GetContext()->Config().GetHTMLFormatter().FormatNucId(ht, *idh.GetSeqId(),
-                        GetContext()->GetScope().GetGi(idh), acc);
+                        GI_TO(TIntId, GetContext()->GetScope().GetGi(idh)), acc);
                 }
 #endif
                 s += comma + sep + "accession " + ht;
