@@ -1,4 +1,4 @@
-/*  $Id: flat_file_config.cpp 606754 2020-04-27 11:09:46Z ivanov $
+/*  $Id: flat_file_config.cpp 614736 2020-08-21 13:43:48Z fukanchi $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -314,15 +314,17 @@ CFlatFileConfig::CFlatFileConfig(
     TStyle style,
     TFlags flags,
     TView view,
-    TPolicy policy) :
-    m_Format(format), m_Mode(mode), m_Style(style), m_Flags(flags), m_View(view), m_Policy(policy)
+    TPolicy policy,
+    TCustom custom) :
+    m_Format(format), m_Mode(mode), m_Style(style), m_Flags(flags), m_View(view), m_Policy(policy), m_Custom(custom)
 {
     m_RefSeqConventions = false;
+    m_FeatDepth = 0;
+    m_GapDepth = 0;
     SetGenbankBlocks(fGenbankBlocks_All);
     SetGenbankBlockCallback(NULL);
     SetCanceledCallback(NULL);
     BasicCleanup(false);
-    SetCustom(0);
 
     // FTable always requires master style
     if (m_Format == eFormat_FTable) {
@@ -535,7 +537,7 @@ void CFlatFileConfig::AddArgumentDescriptions(CArgDescriptions& args)
                                  "Far fetch policy",
                                  CArgDescriptions::eString, "adaptive");
          arg_desc->SetConstraint("policy",
-                                 &(*new CArgAllow_Strings, "adaptive", "internal", "external", "exhaustive"));
+                                 &(*new CArgAllow_Strings, "adaptive", "internal", "external", "exhaustive", "ftp", "web"));
 
          // flags (default: 0)
          arg_desc->AddDefaultKey("flags", "Flags",
@@ -615,6 +617,9 @@ void CFlatFileConfig::AddArgumentDescriptions(CArgDescriptions& args)
          arg_desc->AddOptionalKey("depth", "Depth",
                                   "Exploration depth", CArgDescriptions::eInteger);
 
+         arg_desc->AddOptionalKey("gap-depth", "GapDepth",
+                                  "Gap exploration depth", CArgDescriptions::eInteger);
+
          arg_desc->AddOptionalKey("max_search_segments", "MaxSearchSegments",
                                   "Max number of empty segments to search", CArgDescriptions::eInteger);
 
@@ -746,6 +751,10 @@ CFlatFileConfig::EPolicy x_GetPolicy(const CArgs& args)
         return CFlatFileConfig::ePolicy_External;
     } else if ( Policy == "exhaustive" ) {
         return CFlatFileConfig::ePolicy_Exhaustive;
+    } else if ( Policy == "ftp" ) {
+        return CFlatFileConfig::ePolicy_Ftp;
+    } else if ( Policy == "web" ) {
+        return CFlatFileConfig::ePolicy_Web;
     }
 
     // default
@@ -847,11 +856,6 @@ CFlatFileConfig::ECustom x_GetCustom(const CArgs& args)
 {
     int custom = args["custom"].AsInteger();
 
-    // ID-5865 : Set the "show SNP" and "show CDD" bits based on the value of the
-    // "enable-external" flag.
-    if (args["enable-external"] || args["policy"].AsString() == "external")
-        custom |= (CFlatFileConfig::fShowSNPFeatures | CFlatFileConfig::fShowCDDFeatures);
-
     return (CFlatFileConfig::ECustom)custom;
 }
 
@@ -916,6 +920,24 @@ void CFlatFileConfig::FromArguments(const CArgs& args)
     CFlatFileConfig::TGenbankBlocks genbank_blocks = x_GetGenbankBlocks(args);
     CFlatFileConfig::ECustom        custom         = x_GetCustom(args);
 
+    // ID-5865 : Set the "show SNP" and "show CDD" bits based on the value of the
+    // "enable-external" flag.
+    if (args["no-external"]) {
+        int flg = (int) flags;
+        flg |= CFlatFileConfig::fHideCDDFeatures;
+        flg |= CFlatFileConfig::fHideSNPFeatures;
+        flags = (CFlatFileConfig::EFlags) flg;
+    } else if (args["enable-external"] || args["policy"].AsString() == "external") {
+        int cust = (int) custom;
+        if ((flags & CFlatFileConfig::fHideCDDFeatures) == 0) {
+            cust |= CFlatFileConfig::fShowCDDFeatures;
+        }
+        if ((flags & CFlatFileConfig::fHideSNPFeatures) == 0) {
+            cust |= CFlatFileConfig::fShowSNPFeatures;
+        }
+        custom = (CFlatFileConfig::ECustom) cust;
+    }
+
     SetFormat(format);
     SetMode(mode);
     SetStyle(style);
@@ -925,6 +947,15 @@ void CFlatFileConfig::FromArguments(const CArgs& args)
     m_fGenbankBlocks = genbank_blocks;
     m_BasicCleanup = args["cleanup"];
     SetCustom(custom);
+
+    if( args["depth"] ) {
+        int featDepth = args["depth"].AsInteger();
+        SetFeatDepth(featDepth);
+    }
+    if( args["gap-depth"] ) {
+        int gapDepth = args["gap-depth"].AsInteger();
+        SetGapDepth(gapDepth);
+    }
 }
 
 #ifdef NEW_HTML_FMT
@@ -958,7 +989,7 @@ void CHTMLEmptyFormatter::FormatNucSearch(CNcbiOstream& os, const string& id) co
     os << id;
 }
 
-void CHTMLEmptyFormatter::FormatTaxid(string& str, const int taxid, const string& taxname) const
+void CHTMLEmptyFormatter::FormatTaxid(string& str, const TTaxId taxid, const string& taxname) const
 {
     str = taxname;
 }
