@@ -1,4 +1,4 @@
-/*  $Id: genbank_formatter.cpp 602692 2020-02-28 22:11:47Z kans $
+/*  $Id: genbank_formatter.cpp 615046 2020-08-26 13:40:11Z fukanchi $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
@@ -523,7 +523,7 @@ void CGenbankFormatter::FormatVersion
         version_line << version.GetAccession();
         if ( version.GetGi() > ZERO_GI ) {
             const CFlatFileConfig& cfg = GetContext().GetConfig();
-            if (! cfg.HideGI()) {
+            if (! (cfg.HideGI() || cfg.IsPolicyFtp())) {
                 version_line << "  GI:" << version.GetGi();
             }
         }
@@ -852,7 +852,7 @@ void CGenbankFormatter::FormatReference
     x_Consortium(l, ref, ctx);
     x_Title(l, ref, ctx);
     x_Journal(l, ref, ctx);
-    if (ref.GetPMID() == 0) {  // suppress MEDLINE if has PUBMED
+    if (ref.GetPMID() == ZERO_ENTREZ_ID) {  // suppress MEDLINE if has PUBMED
         x_Medline(l, ref, ctx);
     }
     x_Pubmed(l, ref, ctx);
@@ -1054,10 +1054,10 @@ void CGenbankFormatter::x_Medline
     bool bHtml = ctx.Config().DoHTML();
 
     string strDummy( "[PUBMED-ID]" );
-    if ( ref.GetMUID() != 0 ) {
+    if ( ref.GetMUID() != ZERO_ENTREZ_ID) {
         Wrap(l, GetWidth(), "MEDLINE", strDummy, eSubp);
     }
-    string strPubmed( NStr::IntToString( ref.GetMUID() ) );
+    string strPubmed( NStr::NumericToString( ref.GetMUID() ) );
     if ( bHtml ) {
         string strLink = "<a href=\"";
         strLink += strLinkBasePubmed;
@@ -1079,10 +1079,10 @@ void CGenbankFormatter::x_Pubmed
  CBioseqContext& ctx) const
 {
     
-    if ( ref.GetPMID() == 0 ) {
+    if ( ref.GetPMID() == ZERO_ENTREZ_ID) {
         return;
     }
-    string strPubmed = NStr::IntToString( ref.GetPMID() );
+    string strPubmed = NStr::NumericToString( ref.GetPMID() );
     if ( ctx.Config().DoHTML() ) {
         string strRaw = strPubmed;
         strPubmed = "<a href=\"https://www.ncbi.nlm.nih.gov/pubmed/";
@@ -1498,7 +1498,7 @@ bool s_GetLinkFeatureKey(
     // assembly of the actual string:
 	strLink.reserve(100); // euristical URL length
 #ifdef NEW_HTML_FMT
-    item.GetContext()->Config().GetHTMLFormatter().FormatLocation(strLink, item.GetFeat().GetLocation(), iGi, strRawKey);
+    item.GetContext()->Config().GetHTMLFormatter().FormatLocation(strLink, item.GetFeat().GetLocation(), GI_TO(TIntId, iGi), strRawKey);
 #else
     // check if this is a protein or nucleotide link
     bool is_prot = false;
@@ -1913,7 +1913,7 @@ s_FormatRegularSequencePiece
                 fill(line, line+kLineBufferSize, ' ');
 
                 // add the span stuff
-                TSeqPos length_of_span_before_base_count = 0;
+                length_of_span_before_base_count = 0;
                 if( bHtml ) {
                     string kSpan = " <span class=\"ff_line\" id=\"";
                     kSpan += accn;
