@@ -1,4 +1,4 @@
-/*  $Id: psg_client.cpp 605160 2020-04-07 18:06:40Z ivanov $
+/*  $Id: psg_client.cpp 612393 2020-07-21 13:51:24Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -308,6 +308,7 @@ string CPSG_Queue::SImpl::x_GetAbsPathRef(shared_ptr<const CPSG_Request> user_re
     }
 
     os << ioc.GetClientId();
+    if (const auto hops = user_request->m_Hops) os << "&hops=" << hops;
     return os.str();
 }
 
@@ -1060,6 +1061,11 @@ bool CPSG_Queue::IsEmpty() const
     return m_Impl->Empty();
 }
 
+CPSG_Queue::TApiLock CPSG_Queue::GetApiLock()
+{
+    return SImpl::GetApiLock();
+}
+
 
 END_NCBI_SCOPE
 
