@@ -1,4 +1,4 @@
-/*  $Id: gff2_reader.cpp 603569 2020-03-12 18:23:57Z ivanov $
+/*  $Id: gff2_reader.cpp 610837 2020-06-24 15:29:29Z ivanov $
  * ===========================================================================
  *
  *                            PUBLIC DOMAIN NOTICE
@@ -182,6 +182,44 @@ void CGff2Reader::xPostProcessAnnot(
     }
 }
 
+//  ----------------------------------------------------------------------------
+void
+CGff2Reader::xGetData(
+    ILineReader& lr,
+    TReaderData& readerData)
+//  ----------------------------------------------------------------------------
+{
+    readerData.clear();
+    string line;
+    if (xGetLine(lr, line)) {
+        if (xNeedsNewSeqAnnot(line)) {
+            return;
+        }
+        if (xIsTrackLine(line)) {
+            if (!mCurrentFeatureCount) {
+                xParseTrackLine(line);
+                xGetData(lr, readerData);
+                return;
+            }
+            m_PendingLine = line;
+            return;
+        }
+        if (xIsTrackTerminator(line)) {
+            if (!mCurrentFeatureCount) {
+                xParseTrackLine("track");
+                xGetData(lr, readerData);
+            }
+            return;
+        }
+        if (!xIsCurrentDataType(line)) {
+            xUngetLine(lr);
+            return;
+        }
+    readerData.push_back(TReaderLine{m_uLineNumber, line});
+    }
+    ++m_uDataCount;
+}
+
 //  ----------------------------------------------------------------------------
 void CGff2Reader::xAssignAnnotId(
     CSeq_annot& annot,
@@ -1347,5 +1385,37 @@ bool CGff2Reader::xIsIgnoredFeatureId(
     return false;
 }
 
+//  ---------------------------------------------------------------------------
+bool
+CGff2Reader::xNeedsNewSeqAnnot(
+    const string& line)
+//  ---------------------------------------------------------------------------
+{
+    if (IsInGenbankMode()) {
+        vector<string> columns;
+        NStr::Split(line, "\t ", columns, NStr::eMergeDelims);
+        string seqId = columns[0];
+        if (m_CurrentSeqId == seqId) {
+            return false;
+        }
+        m_CurrentSeqId = seqId;
+        if (mCurrentFeatureCount == 0) {
+            return false;
+        }
+        m_PendingLine = line;
+        return true;
+    }
+    return false;
+}
+
+//  ----------------------------------------------------------------------------
+bool CGff2Reader::IsInGenbankMode() const
+//  ----------------------------------------------------------------------------
+{
+    return (m_iFlags & CGff2Reader::fGenbankMode);
+}
+
+
+
 END_objects_SCOPE
 END_NCBI_SCOPE
